@@ -103,6 +103,7 @@ gail_canvas_group_ref_child (AtkObject *obj,
   GnomeCanvasItem *item;
   AtkObject *accessible;
   GObject *g_obj;
+  GList *list_item;
 
   g_return_val_if_fail (GAIL_IS_CANVAS_ITEM (obj), 0);
   atk_gobject = ATK_GOBJECT_ACCESSIBLE (obj);
@@ -110,8 +111,11 @@ gail_canvas_group_ref_child (AtkObject *obj,
   g_return_val_if_fail (GNOME_IS_CANVAS_GROUP (g_obj), 0);
   group = GNOME_CANVAS_GROUP (g_obj);
 
-  item = GNOME_CANVAS_ITEM(g_list_nth (group->item_list, i)->data);
-  g_return_val_if_fail (item, NULL);
+  list_item = g_list_nth (group->item_list, i);
+  if (!list_item)
+	  return NULL;
+  g_return_val_if_fail (list_item->data, NULL);
+  item = GNOME_CANVAS_ITEM (list_item->data);
   accessible = atk_gobject_accessible_for_object (G_OBJECT (item));
   g_object_ref (accessible);
   return accessible;
